<?php

namespace Ads\Ad\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Form;
use Ads\Ad\Http\Requests\AsdUserRequest;
use Ads\Ad\Interfaces\AsdRepositoryInterface;
use Ads\Ad\Models\Asd;

class AsdUserController extends UserController
{
    /**
     * Initialize asd controller.
     *
     * @param type AsdRepositoryInterface $asd
     *
     * @return type
     */
    public function __construct(AsdRepositoryInterface $asd)
    {
        $this->repository = $asd;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AsdUserRequest $request)
    {
        $this->repository->pushCriteria(new \Lavalite\Ad\Repositories\Criteria\AsdUserCriteria());
        $asds = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('ad::asd.names').' :: ');

        return $this->theme->of('ad::user.asd.index', compact('asds'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Asd $asd
     *
     * @return Response
     */
    public function show(AsdUserRequest $request, Asd $asd)
    {
        Form::populate($asd);

        return $this->theme->of('ad::user.asd.show', compact('asd'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AsdUserRequest $request)
    {

        $asd = $this->repository->newInstance([]);
        Form::populate($asd);

        return $this->theme->of('ad::user.asd.create', compact('asd'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AsdUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $asd = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('ad::asd.name')]);
            $this->responseRedirect = trans_url('/user/ad/asd');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Asd $asd
     *
     * @return Response
     */
    public function edit(AsdUserRequest $request, Asd $asd)
    {

        Form::populate($asd);

        return $this->theme->of('ad::user.asd.edit', compact('asd'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Asd $asd
     *
     * @return Response
     */
    public function update(AsdUserRequest $request, Asd $asd)
    {
        try {
            $this->repository->update($request->all(), $asd->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('ad::asd.name')]);
            $this->responseRedirect = trans_url('/user/ad/asd');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AsdUserRequest $request, Asd $asd)
    {
        try {
            $this->repository->delete($asd->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('ad::asd.name')]);
            $this->responseRedirect = trans_url('/user/ad/asd');
            return $this -> respond($request);
        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
